@@ -1951,10 +1951,10 @@ mc_account_is_complete (McAccount *account)
 
       param = (McProtocolParam *) tmp->data;
 
-      if (!(param->flags & MC_PROTOCOL_PARAM_REQUIRED))
+      if (!param || !(param->flags & MC_PROTOCOL_PARAM_REQUIRED))
         continue;
 
-      if (param == NULL || param->name == NULL || param->signature == NULL)
+      if (param->name == NULL || param->signature == NULL)
         {
           ret = FALSE;
           break;
@@ -2135,7 +2135,8 @@ mc_account_set_avatar_from_data (McAccount *account, const gchar *data,
 	/* create an empty file; this will cause MC to clear the current
 	 * avatar */
 	FILE *f_out = fopen (filename_out, "w");
-	fclose (f_out);
+	if (G_LIKELY (f_out))
+	    fclose (f_out);
     }
 
     client = gconf_client_get_default ();
