@@ -118,14 +118,14 @@ _mcd_master_init_managers (McdMaster * master)
     /* Let the presence frame know what accounts we have */
     mcd_presence_frame_set_accounts (priv->presence_frame, acct_head);
 
-    for (acct = acct_head; acct; acct = g_list_next (acct))
+    for (acct = acct_head; acct; acct = acct->next)
     {
 	McAccount *account;
 	McProfile *profile;
 	McProtocol *protocol;
 	McManager *mc_manager;
 
-	account = acct ? acct->data : NULL;
+	account = acct->data;
 	profile = account ? mc_account_get_profile (account) : NULL;
 	protocol = profile ? mc_profile_get_protocol (profile) : NULL;
 	mc_manager = protocol ? mc_protocol_get_manager (protocol) : NULL;
@@ -275,6 +275,7 @@ _mcd_master_on_account_enabled (McAccountMonitor * monitor,
     g_debug ("Account %s enabled", account_name);
 
     account = mc_account_lookup (account_name);
+    if (G_UNLIKELY (!account)) return;
     manager = _mcd_master_find_potential_manager (master, account);
 
     if (manager == NULL)
